;***************************************************************************
;*         File: buttons.bb
;*     Coded By: Krylar
;* Last Updated: 05/19/02
;***************************************************************************

; define the type for this library
Type Buttons
     Field Set$				; the name of the set that *this* button belongs to
     Field Image			; the handle to the image
     Field X				; where the button will be displayed on X
     Field Y				; where the button will be displayed on Y
     Field Width			; how wide is the button?
     Field Height			; how high is the button?
     Field ReturnValue$		; what value should be returned if this button is hit?
     Field DelayTimer       ; are we delaying?
     Field DelayAmount      ; millisecs to show the depress graphic
     Field ButtonType       ; 0=Normal, 1=Toggle, 2-n = List toggle
     Field Status           ; 0=Out, 1=In
End Type

; define a global so we can process the button anywhere
Global Button.Buttons

;**********************************************************************************
; FUNCTION: Buttons_Create(Set$,Filename$,X,Y,ReturnValue$,DelayAmount)
;   Author: Krylar
; Last Updated: 10/18/2001
;
; Creates an instance of Type Buttons.
;
; Arguments:
;           Set: What set is this with?
;      Filename: What is the image filename?
;           X,Y: Where is the button's top-left corner to be?
;    ButtonType: 0 = regular, 1 = toggle, 2-n = List toggle
;   ReturnValue: What should be returned if the button is pressed?
;   DelayAmount: How long should the button be pressed in before releasing?
;
; RETURNS:
;             0 = All was fine
;            -1 = Could not load the image
;            -2 = Could not allocate the type
;**********************************************************************************
Function Buttons_Create(Set$,Filename$,X,Y,ButtonType,ReturnValue$,DelayAmount)
    ButtonImage = LoadImage(FileName$)
    Width = ImageWidth(ButtonImage) / 2
    Height = ImageHeight(ButtonImage)
    FreeImage ButtonImage
    ButtonImage = LoadAnimImage(FileName$,Width,Height,0,2)
    If ButtonImage = 0
       Return -1
    Else
       Button.Buttons = New Buttons
       If Button = Null
          Return -2
       Else
          Button\Set$ = Set$
          Button\Image = ButtonImage
          Button\X = X
          Button\Y = Y
          Button\ButtonType = ButtonType
          Button\Status = 0
          Button\Width = ImageWidth(ButtonImage)
          Button\Height = ImageHeight(ButtonImage)
          Button\ReturnValue$ = ReturnValue$
          Button\DelayAmount = DelayAmount
       EndIf       
    EndIf
    Return 0
End Function


;*****************************************************************************
; FUNCTION: Buttons_Show(Set$)
;   Author: Krylar
; Last Updated: 10/18/2001
;
; Displays the current buttons based on the requested set
;
; RETURNS:  n/a
;*****************************************************************************
Function Buttons_Show(Set$)
    For Button.Buttons = Each Buttons
        If Button\Set$ = Set$
           If Button\ButtonType = 0
          		 If MouseDown(1) = True And Button\Status = 1
                	 Button\Status = 1
				 ElseIf MouseDown(1) = False And Button\Status = 1
					 Button\Status = 0
				 EndIf
           EndIf
           DrawBlock Button\Image,Button\X,Button\Y,Button\Status
       EndIf       
    Next
End Function

;*****************************************************************************
; FUNCTION: Buttons_Check$(Set$)
;   Author: Krylar
; Last Updated: 10/18/2001
;
; Checks the current buttons for click, depresses if so, delays appropriately,
; and returns the button's "ReturnValue".
;
; RETURNS:  
;                "NONE" = No buttons clicked
;          ReturnValue$ = the "ReturnValue" of the clicked button
;*****************************************************************************
Function Buttons_Check$(Set$)
    ResetButtonToggles = 0
    X = MouseX()
    Y = MouseY()

    For Button.Buttons = Each Buttons
        If Button\Set$ = Set$
           If X >= Button\X And X <= Button\X + Button\Width And Y >= Button\Y And Y <= Button\Y + Button\Height
              If Button\ButtonType = 0
                 ;DrawImage Button\Image,Button\X,Button\Y,1
                 Button\Status = 1
                 Button\DelayTimer = MilliSecs()
                 Return Button\ReturnValue$
              EndIf
              If Button\ButtonType = 1
                 If Button\Status = 0
                    Button\Status = 1
                 Else
                    Button\Status = 0
                 EndIf
                 DrawBlock Button\Image,Button\X,Button\Y,Button\Status
                 ReturnValue$ = Button\ReturnValue$ + "" + Button\Status
                 Return ReturnValue$ 
              EndIf

              If Button\ButtonType <> 0 And Button\ButtonType <> 1
                 ResetButtonToggles = 1
                 ButtonType = Button\ButtonType
              EndIf
           EndIf
       EndIf       
    Next

    If ResetButtonToggles = 1
       For Button.Buttons = Each Buttons
           If Button\Set$ = Set$ And Button\ButtonType = ButtonType
              If X >= Button\X And X <= Button\X + Button\Width And Y >= Button\Y And Y <= Button\Y + Button\Height
                 Button\Status = 1
                 DrawBlock Button\Image,Button\X,Button\Y,Button\Status
                 ReturnValue$ = Button\ReturnValue$
              Else
                 Button\Status = 0
              EndIf
           EndIf                  
       Next
       Return ReturnValue$
    EndIf

    Return "NONE"
End Function


;*****************************************************************************
; FUNCTION: Buttons_ToggleOff(Set$,ButtonValue$)
;   Author: Krylar
; Last Updated: 10/18/2001
;
; Forces a toggle button to off
;*****************************************************************************
Function Buttons_ToggleOff(Set$,ButtonValue$)
    For Button.Buttons = Each Buttons
        If Button\Set$ = Set$
           If Button\ReturnValue$ = ButtonValue$
              If Button\Status = 1
                 Button\Status = 0
              EndIf
              DrawBlock Button\Image,Button\X,Button\Y,Button\Status
           EndIf
       EndIf       
    Next
End Function


;*****************************************************************************
; FUNCTION: Buttons_ToggleOn(Set$,ButtonValue$)
;   Author: Krylar
; Last Updated: 10/18/2001
;
; Forces a toggle button to on
;*****************************************************************************
Function Buttons_ToggleOn(Set$,ButtonValue$)
    For Button.Buttons = Each Buttons
        If Button\Set$ = Set$
           If Button\ReturnValue$ = ButtonValue$
              If Button\Status = 0
                 Button\Status = 1
              EndIf
              DrawBlock Button\Image,Button\X,Button\Y,Button\Status
           EndIf
       EndIf       
    Next
End Function


;*****************************************************************************
; FUNCTION: Buttons_Delay(Set$,ButtonValue$)
;   Author: Krylar
; Last Updated: 10/18/2001
;
; calls the Blitz Delay function for a specified amount
;
; RETURNS:  0, just to quickly bail from the function
;*****************************************************************************
Function Buttons_Delay(Set$,ButtonValue$)
    For Button.Buttons = Each Buttons
        If Button\Set$ = Set$
           If Button\ReturnValue$ = ButtonValue$
              Delay(Button\DelayAmount)
              Return 0
           EndIf
       EndIf       
    Next
End Function


;*****************************************************************************
; FUNCTION: Buttons_Delete(Set$)
;   Author: Krylar
; Last Updated: 11/06/2001
;
; Deletes the current buttons based on the requested set
;
; RETURNS:  n/a
;*****************************************************************************
Function Buttons_Delete(Set$)
    For Button.Buttons = Each Buttons
        If Button\Set$ = Set$
           Delete Button
       EndIf       
    Next
End Function